@@ -1,20 +1,21 @@
 """
-Finary Assistant is a tool to organize your investments in a custom hierarchy, 
-fetch real-time values using Finary API, set targets, and simulate your 
+Finary Assistant is a tool to organize your investments in a custom hierarchy,
+fetch real-time values using Finary API, set targets, and simulate your
 portfolio evolution with optional life events and portfolio operations.
 
 This module is maintained by MadeInPierre.
 You can always get the latest version of this module at:
     https://github.com/madeinpierre/finary_assistant
 """
-
-
+# flake8: noqa
 # Import meta information such as version, author, copyright, etc.
-from __meta__ import *
-
 import os
 import sys
 
+from .__meta__ import __author__  # noqa: F401
+from .__meta__ import __copyright__  # noqa: F401
+from .__meta__ import __version__  # noqa: F401
+
 # add finary_api submodule to path to allow imports to work
 sys.path.append(os.path.join(os.path.dirname(__file__), "finary_api"))
 
