@@ -1,8 +1,11 @@
+# flake8: noqa
 from ..console import console
-from .folder import Folder, FolderDisplay
+from .bucket import Bucket
+from .bucket import SharedFolder
+from .folder import Folder
+from .folder import FolderDisplay
+from .hierarchy import Hierarchy
 from .line import Line
 from .node import Node
-from .hierarchy import Hierarchy
 from .portfolio import Portfolio
 from .targets import *
-from .bucket import Bucket, SharedFolder
